@@ -1,6 +1,8 @@
 import os
 from keyring import get_password
+from keyrings.alt.file import PlaintextKeyring
 from werkzeug.utils import import_string
+import keyring.backend
 
 DB = "calculator_service"
 PORT = 27017
@@ -56,6 +58,7 @@ config = {
 
 
 def configure_app():
+    keyring.set_keyring(PlaintextKeyring())
     config_name = os.getenv('FLASK_ENV', "cryptodataaccess.config.DevelopmentConfig")
     cfg = import_string(config_name)()
     cfg.USERNAME = get_password('cryptodataaccess', 'USERNAME')
