@@ -67,14 +67,13 @@ def test_fetch_prices_and_symbols():
     prices.objects.all().delete()
     insert_prices_record()
 
-    dt = convert_to_int_timestamp(datetime(year=2020, month = 7 , day = 3 ))
+    dt = convert_to_int_timestamp(datetime(year=2020, month=7, day=3))
     objs = repo.fetch_latest_prices_to_date(dt)
     assert (len(objs) == 1)
     objs = repo.fetch_latest_prices_to_date(dt)
 
     dt = convert_to_int_timestamp(datetime(year=2020, month=7, day=4))
 
-
     assert (len(objs) == 1)
     symbols = repo.fetch_symbols()
     assert (len(symbols) == 100)
@@ -128,7 +127,7 @@ def test_update_notification_when_does_not_exist_throws_ValueError():
             source_id=ObjectId('666f6f2d6261722d71757578'),
             check_every="00:00",
             start_date=datetime.now(),
-            end_date= datetime.now(),
+            end_date=datetime.now(),
             threshold_value=1
 
         )
@@ -156,7 +155,7 @@ def test_update_notification():
 
     repo.edit_notification(in_id=un.id,
                            user_id=1, user_name='username2', user_email='email',
-                           notification_type='BALANCE',     check_every="00:00",
+                           notification_type='BALANCE', check_every="00:00",
                            start_date=datetime.now(),
                            end_date=datetime.now(),
                            is_active=True, channel_type='TELEGRAM',
@@ -168,7 +167,7 @@ def test_update_notification():
     assert (un.user_name == "username2")
     repo.edit_notification(in_id=un.id,
                            user_id=1, user_name='username2', user_email='email',
-                           notification_type='BALANCE',     check_every="00:00",
+                           notification_type='BALANCE', check_every="00:00",
                            start_date=datetime.now(),
                            end_date=datetime.now(),
                            is_active=True, channel_type='TELEGRAM',
@@ -189,7 +188,7 @@ def test_delete_notification_when_exists():
 
     repo.add_notification(user_id=1, user_name='username', user_email='email',
                           threshold_value=1,
-                          notification_type = "BALANCE",
+                          notification_type="BALANCE",
                           check_every="00:00",
                           start_date=datetime.now(),
                           end_date=datetime.now(),
@@ -204,8 +203,6 @@ def test_delete_notification_when_exists():
     assert (len(user_notification.objects) == 0)
 
 
-
-
 def test_fetch_notification_when_exists():
     config = configure_app()
     store = UsersMongoStore(config, mock_log)
@@ -216,7 +213,7 @@ def test_fetch_notification_when_exists():
 
     repo.add_notification(user_id=1, user_name='username', user_email='email',
                           threshold_value=1,
-                          notification_type = "BALANCE",
+                          notification_type="BALANCE",
                           check_every="00:00",
                           start_date=datetime.now(),
                           end_date=datetime.now(),
@@ -232,6 +229,19 @@ def test_fetch_notification_when_exists():
     assert (ut.user_name == "username")
 
 
+def test_fetch_notification_when_does_not_exists():
+    config = configure_app()
+    store = UsersMongoStore(config, mock_log)
+    repo = UsersRepository(store)
+    helpers.do_connect(config)
+
+    user_notification.objects.all().delete()
+
+    ut = repo.get_notification(ObjectId('666f6f2d6261722d71757578'))
+
+    assert (len(ut) == 0)
+
+
 def test_delete_user_notification_when_exists_by_source_id():
     config = configure_app()
     store = UsersMongoStore(config, mock_log)
@@ -292,9 +302,9 @@ def test_do_delete_notification_when_does_not_exist_should_not_throw():
 
     noti = user_notification()
     noti.id = ObjectId('666f6f2d6261722d71757578')
-    noti.source_id =ObjectId('666f6f2d6261722d71757578')
-    store.delete_notification(notification=noti,throw_if_does_not_exist=False)
-    assert(1==1)
+    noti.source_id = ObjectId('666f6f2d6261722d71757578')
+    store.delete_notification(notification=noti, throw_if_does_not_exist=False)
+    assert (1 == 1)
 
 
 def test_remove_notification_by_source_id_should_not_add_any_object_to_memory_when_does_not_exist_in_db_and_mem():
@@ -304,8 +314,9 @@ def test_remove_notification_by_source_id_should_not_add_any_object_to_memory_wh
     helpers.do_connect(config)
     user_notification.objects.all().delete()
 
-    store.do_delete_user_notification_by_source_id(source_id= ObjectId('666f6f2d6261722d71757578'), throw_if_does_not_exist=False)
-    assert (len(repo.memories[USER_NOTIFICATIONS_MEMORY_KEY].items)==0)
+    store.do_delete_user_notification_by_source_id(source_id=ObjectId('666f6f2d6261722d71757578'),
+                                                   throw_if_does_not_exist=False)
+    assert (len(repo.memories[USER_NOTIFICATIONS_MEMORY_KEY].items) == 0)
 
 
 def test_delete_notification_by_source_id_should_not_add_any_object_to_memory_when_does_not_exist_in_db_and_mem():
@@ -315,8 +326,9 @@ def test_delete_notification_by_source_id_should_not_add_any_object_to_memory_wh
     helpers.do_connect(config)
     user_notification.objects.all().delete()
 
-    store.do_delete_user_notification_by_source_id(source_id= ObjectId('666f6f2d6261722d71757578'), throw_if_does_not_exist=False)
-    assert (len(repo.memories[USER_NOTIFICATIONS_MEMORY_KEY].items)==0)
+    store.do_delete_user_notification_by_source_id(source_id=ObjectId('666f6f2d6261722d71757578'),
+                                                   throw_if_does_not_exist=False)
+    assert (len(repo.memories[USER_NOTIFICATIONS_MEMORY_KEY].items) == 0)
 
 
 def test_remove_notification_by_source_id_should_not_add_any_object_to_memory_when_does_not_exist_in_db_and_mem():
@@ -328,4 +340,3 @@ def test_remove_notification_by_source_id_should_not_add_any_object_to_memory_wh
 
     repo.remove_notification_by_source_id(source_id=ObjectId('666f6f2d6261722d71757578'))
     assert (len(repo.memories[USER_NOTIFICATIONS_MEMORY_KEY].items) == 0)
-
